import { Result } from 'postcss';
import webpack from 'webpack';
import { TailwindConfig } from 'tailwindcss/tailwind-config';
import http from 'http';

declare class DevtoolsServer {
    host: string;
    port: number;
    server: http.Server;
    service: Compiler['$tailwind'];
    _listen: boolean;
    constructor(options: UserOptions, compiler: Compiler);
    _ensureStart: () => Promise<{
        port: number;
        host: string;
    }>;
    ensureStart(): Promise<{
        port: number;
        host: string;
    }>;
    close(callback?: (err?: Error) => void): void;
}

declare type ChangedContent = {
    content: string;
    extension: string;
}[];
declare type Service = {
    tailwindConfig: TailwindConfig | null;
    context: any;
    configDependencies: Set<string>;
    transformCSS: (source: string) => Promise<Result>;
    updateChangedContent: (changed: ChangedContent) => void;
    clearChangedContent: () => void;
    getCompletions: () => string;
    ensureInit: () => void;
    invalidateCssModule: () => void;
    refresh: () => void;
};
declare type Compiler = {
    $tailwind: {
        dirty: Set<string>;
        server: DevtoolsServer;
        service: Service;
    };
} & webpack.Compiler;
declare type DevtoolOptions = {
    port?: number;
    host?: string;
};
declare type UserOptions = {
    config?: TailwindConfig | string;
    devtools?: DevtoolOptions;
    entry?: string;
};

declare class TailwindCSSWebpackPlugin {
    options: UserOptions;
    constructor(options?: UserOptions);
    apply(compiler: Compiler): void;
}

export { TailwindCSSWebpackPlugin };
