// src/loaders/devtools-loader.ts
import { readFileSync } from "fs";

// src/util.ts
import createDebugger from "debug";
import tailwind from "tailwindcss/lib/processTailwindFeatures";
import getModuleDependencies from "tailwindcss/lib/lib/getModuleDependencies";
import resolveConfig from "tailwindcss/resolveConfig";
import normalizePath from "normalize-path";
import fastGlob from "fast-glob";

// src/devtools/server.ts
import { getPort } from "get-port-please";
import createServer from "tailwind-config-viewer/server";

// src/constants.ts
var PLUGIN_NAME = "tailwindcss-webpack-plugin";
var DEVTOOLS_POST_PATH = "/_tailwindcss_devtools_update";
var COMPILE_ENTRY_PATH = new URL("./templates/_compile-entry_.js", import.meta.url).pathname;
var TAILWIND_ENTRY_PATH = new URL("./templates/_tailwind_.css", import.meta.url).pathname;
var DEVTOOLS_ENTRY_PATH = new URL("./templates/_tailwind-devtools_.js", import.meta.url).pathname;
var DEVTOOLS_LOADER_PATH = new URL("./loaders/devtools-loader.js", import.meta.url).pathname;
var CSS_LOADER_PATH = new URL("./loaders/css-loader.js", import.meta.url).pathname;

// src/util.ts
var debug = createDebugger(PLUGIN_NAME);
var isWebTarget = (target) => {
  let isWeb = true;
  const _isWebTarget = (checked) => !checked.includes("node") && !checked.includes("electron-preload") && !checked.includes("electron-main") && !checked.includes("nwjs");
  if (typeof target === "string") {
    isWeb = _isWebTarget(target);
  } else if (Array.isArray(target)) {
    target.forEach((checked) => {
      if (!_isWebTarget(checked)) {
        isWeb = false;
        return;
      }
    });
  }
  return isWeb;
};
var isDev = () => process.env.NODE_ENV === "development";

// src/loaders/devtools-loader.ts
var DEVTOOLS_CLIENT_PATH = new URL("../devtools/client.js", import.meta.url);
async function devtoolsLoader(source) {
  const callback = this.async();
  if (!this._compiler) {
    callback(null, source);
    return;
  }
  this.cacheable(false);
  if (isWebTarget(this._compiler.options.target) && isDev()) {
    await this._compiler.$tailwind.service.ensureInit();
    const { port, host } = await this._compiler.$tailwind.server.ensureStart();
    debug(`[devtools-loader]: backend server started`);
    const clientContent = readFileSync(DEVTOOLS_CLIENT_PATH, "utf-8").replace("__POST_PATH__", `http://${host}:${port}${DEVTOOLS_POST_PATH}`).replace("__CONFIG_VIEWER_PATH__", `http://${host}:${port}`);
    const completions = this._compiler.$tailwind.service.getCompletions();
    debug(`[devtools-loader]: completions generated`);
    callback(null, `${clientContent}
${completions}`);
  } else {
    callback(null, "");
  }
}
export {
  devtoolsLoader as default
};
